<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Artisan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Log;

class BackupController extends Controller
{
    public function runBackup()
    {
        try {
            // Jalankan Artisan Command
            Artisan::call('db:backup-sql');

            $backupFileName = Artisan::output();

            return response()->json([
                'success' => true,
                'message' => 'Backup database berhasil.',
                'file' => url('/storage/Laravel/' . trim($backupFileName)),
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Gagal menjalankan backup database: ' . $e->getMessage(),
            ], 500);
        }
    }

    public function getBackupFiles()
    {
        $files = Storage::disk('local')->files('Laravel');
        
        $sqlFiles = array_filter($files, function($file) {
            // return pathinfo($file, PATHINFO_EXTENSION) === 'sql';
            return preg_match('/^backup-\d{4}-\d{2}-\d{2}_\d{2}-\d{2}-\d{2}\.sql$/', basename($file));
        });

        return response()->json([
            'success' => true,
            'files' => $sqlFiles,
        ]);
    }

    public function downloadBackupFile($file)
    {
        $filePath = storage_path('app/Laravel/' . $file);

        if (Storage::disk('local')->exists('Laravel/' . $file)) {
            return response()->download($filePath, $file, [
                'Content-Type' => 'application/octet-stream',
                'Content-Disposition' => 'attachment; filename="' . $file . '"'
            ]);
        }

        return response()->json([
            'success' => false,
            'message' => 'File not found.',
        ], Response::HTTP_NOT_FOUND);
    }

    public function deleteBackupFile($file)
    {
        $filePath = 'Laravel/' . $file;

        if (Storage::disk('local')->exists($filePath)) {
            Storage::disk('local')->delete($filePath);

            return response()->json([
                'success' => true,
                'message' => 'File successfully deleted.',
            ]);
        }

        return response()->json([
            'success' => false,
            'message' => 'File not found.',
        ], 404);
    }
}
